/*
 * Copyright (c) 2004 Your Corporation. All Rights Reserved.
 */
package org.skife.derby.groovy;

import junit.framework.TestCase;
import org.skife.jdbi.DBI;
import org.skife.jdbi.Handle;

import java.util.Collection;
import java.util.Iterator;
import java.util.Map;
import java.sql.Timestamp;
import java.math.BigDecimal;

public class TestFunctions extends TestCase
{

    public void setUp() throws Exception
    {
        Tools.start();
    }

    public void tearDown() throws Exception
    {
        Tools.stop();
    }

    public void testString() throws Exception
    {
        final Handle h = DBI.open(Tools.CONN_STRING);
        h.script("load-groovy-jars");
        h.script("create-groovy");
        final Collection r = h.query("values groovy_string('7 + 6')");
        final Iterator i = r.iterator();
        assertTrue(i.hasNext());
        final Map row = (Map) i.next();
        assertEquals("13", row.get("1"));
    }

    public void testInt() throws Exception
    {
        final Handle h = DBI.open(Tools.CONN_STRING);
        h.script("load-groovy-jars");
        h.script("create-groovy");
        final Collection r = h.query("values groovy_int('7 + 6')");
        final Iterator i = r.iterator();
        assertTrue(i.hasNext());
        final Map row = (Map) i.next();
        assertEquals(new Integer(13), row.get("1"));
    }

    public void testTimestamp() throws Exception
    {
        final Handle h = DBI.open(Tools.CONN_STRING);
        h.script("load-groovy-jars");
        h.script("create-groovy");
        final Collection r = h.query("values groovy_timestamp('new java.sql.Timestamp(7)')");
        final Iterator i = r.iterator();
        assertTrue(i.hasNext());
        final Map row = (Map) i.next();
        assertEquals(new Timestamp(7), row.get("1"));
    }

    public void testDecimal() throws Exception
    {
        final Handle h = DBI.open(Tools.CONN_STRING);
        h.script("load-groovy-jars");
        h.script("create-groovy");
        final Collection r = h.query("values groovy_decimal('(7.0 / 2.0)')");
        final Iterator i = r.iterator();
        assertTrue(i.hasNext());
        final Map row = (Map) i.next();
        assertEquals(new BigDecimal(3.0), row.get("1"));
    }

    public void testSqlAvailable() throws Exception
    {
        final Handle h = DBI.open(Tools.CONN_STRING);
        h.script("load-groovy-jars");
        h.script("create-groovy");
        final Collection r = h.query("fancy");
        final Iterator i = r.iterator();
        assertTrue(i.hasNext());
        final Map row = (Map) i.next();
        assertTrue(row.get("1").toString().startsWith("groovy.sql.Sql"));
    }

    public void testProc() throws Exception
    {
        final Handle h = DBI.open(Tools.CONN_STRING);
        h.execute("create table something ( id integer )");
        h.script("load-groovy-jars");
        h.script("create-groovy");
        h.execute("use-the-proc");
        final Collection r = h.query("select id from something");
        final Iterator i = r.iterator();
        assertTrue(i.hasNext());
        final Map row = (Map) i.next();
        assertEquals(new Integer(7), row.get("id"));
    }
}
