/* Copyright 2004 Brian McCallister
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.skife.derby.groovy;

import org.apache.commons.io.FileUtils;
import org.apache.derby.jdbc.EmbeddedDriver;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.sql.Connection;
import java.sql.Driver;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Properties;

public class Tools
{
    public static final String CONN_STRING = "jdbc:derby:testing";
    public static Driver driver;

    public static final void start() throws SQLException, IOException
    {
        System.setProperty("derby.system.home", "build/db");
        File db = new File("build/db");
        FileUtils.deleteDirectory(db);
        db.mkdirs();
        final Properties derby = new Properties();
        derby.setProperty("derby.storage.fileSyncTransactionLog", "true");
        FileOutputStream outs = new FileOutputStream("build/db/derby.properties");
        derby.store(outs, "auto-generated properties for unit testing");
        driver = new EmbeddedDriver();
        DriverManager.registerDriver(driver);

        final Connection conn = DriverManager.getConnection("jdbc:derby:testing;create=true");
        conn.close();
    }

    public final static void stop() throws IOException
    {
        try
        {
            DriverManager.getConnection("jdbc:derby:testing;shutdown=true");
        }
        catch (SQLException e)
        {
            // expected
        }
        FileUtils.deleteDirectory(new File("build/db"));
        try
        {
            DriverManager.deregisterDriver(driver);
        }
        catch (SQLException e)
        {
            e.printStackTrace();
        }
        System.gc();
    }

    public static final Connection getConnection() throws SQLException
    {
        return DriverManager.getConnection(CONN_STRING);
    }

    public static final void createTestSchema() throws SQLException
    {
        final Connection conn = getConnection();
        final Statement stmt = conn.createStatement();

        stmt.execute("create table something ( id integer, name varchar(50) )");

        stmt.close();
        conn.close();
    }
}
